# jfjoch-client
API to control Jungfraujoch developed by the Paul Scherrer Institute (Switzerland).
Jungfraujoch is a data acquisition and analysis system for pixel array detectors, primarly PSI JUNGFRAU.
Jungfraujoch uses FPGA boards to acquire data at high data rates.


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.0-rc.22
- Package version: 1.0.0-rc.22
- Generator version: 7.8.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://git.psi.ch/jungfraujoch/jungfraujoch.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://git.psi.ch/jungfraujoch/jungfraujoch.git`)

Then import the package:
```python
import jfjoch_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import jfjoch_client
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import jfjoch_client
from jfjoch_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost:5232
# See configuration.py for a list of all supported configuration parameters.
configuration = jfjoch_client.Configuration(
    host = "http://localhost:5232"
)



# Enter a context with an instance of the API client
with jfjoch_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = jfjoch_client.DefaultApi(api_client)

    try:
        # Cancel running data collection
        api_instance.cancel_post()
    except ApiException as e:
        print("Exception when calling DefaultApi->cancel_post: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost:5232*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DefaultApi* | [**cancel_post**](docs/DefaultApi.md#cancel_post) | **POST** /cancel | Cancel running data collection
*DefaultApi* | [**config_azim_int_get**](docs/DefaultApi.md#config_azim_int_get) | **GET** /config/azim_int | Get radial integration configuration
*DefaultApi* | [**config_azim_int_put**](docs/DefaultApi.md#config_azim_int_put) | **PUT** /config/azim_int | Configure radial integration
*DefaultApi* | [**config_detector_get**](docs/DefaultApi.md#config_detector_get) | **GET** /config/detector | Get detector configuration
*DefaultApi* | [**config_detector_put**](docs/DefaultApi.md#config_detector_put) | **PUT** /config/detector | Change detector configuration
*DefaultApi* | [**config_image_format_conversion_post**](docs/DefaultApi.md#config_image_format_conversion_post) | **POST** /config/image_format/conversion | Configure format for data collection with full conversion
*DefaultApi* | [**config_image_format_get**](docs/DefaultApi.md#config_image_format_get) | **GET** /config/image_format | Get image output format
*DefaultApi* | [**config_image_format_put**](docs/DefaultApi.md#config_image_format_put) | **PUT** /config/image_format | Change image output format
*DefaultApi* | [**config_image_format_raw_post**](docs/DefaultApi.md#config_image_format_raw_post) | **POST** /config/image_format/raw | Configure format for raw data collection
*DefaultApi* | [**config_instrument_get**](docs/DefaultApi.md#config_instrument_get) | **GET** /config/instrument | Get instrument metadata
*DefaultApi* | [**config_instrument_put**](docs/DefaultApi.md#config_instrument_put) | **PUT** /config/instrument | Change instrument metadata
*DefaultApi* | [**config_internal_generator_image_put**](docs/DefaultApi.md#config_internal_generator_image_put) | **PUT** /config/internal_generator_image | Load binary image for internal FPGA generator
*DefaultApi* | [**config_internal_generator_image_tiff_put**](docs/DefaultApi.md#config_internal_generator_image_tiff_put) | **PUT** /config/internal_generator_image.tiff | Load TIFF image for internal FPGA generator
*DefaultApi* | [**config_mask_tiff_get**](docs/DefaultApi.md#config_mask_tiff_get) | **GET** /config/mask.tiff | Get mask of the detector
*DefaultApi* | [**config_select_detector_get**](docs/DefaultApi.md#config_select_detector_get) | **GET** /config/select_detector | List available detectors
*DefaultApi* | [**config_select_detector_put**](docs/DefaultApi.md#config_select_detector_put) | **PUT** /config/select_detector | Select detector
*DefaultApi* | [**config_spot_finding_get**](docs/DefaultApi.md#config_spot_finding_get) | **GET** /config/spot_finding | Get data processing configuration
*DefaultApi* | [**config_spot_finding_put**](docs/DefaultApi.md#config_spot_finding_put) | **PUT** /config/spot_finding | Configure spot finding
*DefaultApi* | [**config_user_mask_tiff_get**](docs/DefaultApi.md#config_user_mask_tiff_get) | **GET** /config/user_mask.tiff | Get user mask of the detector
*DefaultApi* | [**config_user_mask_tiff_put**](docs/DefaultApi.md#config_user_mask_tiff_put) | **PUT** /config/user_mask.tiff | Upload user mask of the detector
*DefaultApi* | [**config_zeromq_preview_get**](docs/DefaultApi.md#config_zeromq_preview_get) | **GET** /config/zeromq_preview | Get ZeroMQ preview settings
*DefaultApi* | [**config_zeromq_preview_put**](docs/DefaultApi.md#config_zeromq_preview_put) | **PUT** /config/zeromq_preview | Set ZeroMQ preview settings
*DefaultApi* | [**deactivate_post**](docs/DefaultApi.md#deactivate_post) | **POST** /deactivate | Prepare detector to turn off
*DefaultApi* | [**detector_status_get**](docs/DefaultApi.md#detector_status_get) | **GET** /detector/status | Get detector status
*DefaultApi* | [**fpga_status_get**](docs/DefaultApi.md#fpga_status_get) | **GET** /fpga_status | Get status of FPGA devices
*DefaultApi* | [**initialize_post**](docs/DefaultApi.md#initialize_post) | **POST** /initialize | Initialize detector and data acquisition
*DefaultApi* | [**pedestal_post**](docs/DefaultApi.md#pedestal_post) | **POST** /pedestal | Collect dark current for the detector
*DefaultApi* | [**plot_azim_int_get**](docs/DefaultApi.md#plot_azim_int_get) | **GET** /plot/azim_int | Generate radial integration profile
*DefaultApi* | [**plot_bkg_estimate_get**](docs/DefaultApi.md#plot_bkg_estimate_get) | **GET** /plot/bkg_estimate | Generate background estimate plot
*DefaultApi* | [**plot_error_pixel_get**](docs/DefaultApi.md#plot_error_pixel_get) | **GET** /plot/error_pixel | Generate error pixels plot
*DefaultApi* | [**plot_image_collection_efficiency_get**](docs/DefaultApi.md#plot_image_collection_efficiency_get) | **GET** /plot/image_collection_efficiency | Generate image collection efficiency plot
*DefaultApi* | [**plot_indexing_rate_get**](docs/DefaultApi.md#plot_indexing_rate_get) | **GET** /plot/indexing_rate | Generate indexing rate plot
*DefaultApi* | [**plot_receiver_delay_get**](docs/DefaultApi.md#plot_receiver_delay_get) | **GET** /plot/receiver_delay | Generate receiver delay plot
*DefaultApi* | [**plot_receiver_free_send_buffers_get**](docs/DefaultApi.md#plot_receiver_free_send_buffers_get) | **GET** /plot/receiver_free_send_buffers | Generate receiver free send buffer plot
*DefaultApi* | [**plot_roi_max_count_get**](docs/DefaultApi.md#plot_roi_max_count_get) | **GET** /plot/roi_max_count | Generate plot of ROI max count
*DefaultApi* | [**plot_roi_sum_get**](docs/DefaultApi.md#plot_roi_sum_get) | **GET** /plot/roi_sum | Generate ROI sum plot
*DefaultApi* | [**plot_roi_valid_pixels_get**](docs/DefaultApi.md#plot_roi_valid_pixels_get) | **GET** /plot/roi_valid_pixels | Generate plot of ROI valid pixels
*DefaultApi* | [**plot_spot_count_get**](docs/DefaultApi.md#plot_spot_count_get) | **GET** /plot/spot_count | Generate spot count plot
*DefaultApi* | [**plot_strong_pixel_get**](docs/DefaultApi.md#plot_strong_pixel_get) | **GET** /plot/strong_pixel | Generate strong pixels plot
*DefaultApi* | [**preview_calibration_tiff_get**](docs/DefaultApi.md#preview_calibration_tiff_get) | **GET** /preview/calibration.tiff | Get last preview image in TIFF format for calibration with PyFAI/Dioptas
*DefaultApi* | [**preview_image_jpeg_get**](docs/DefaultApi.md#preview_image_jpeg_get) | **GET** /preview/image.jpeg | Get last preview image in JPEG format using default settings
*DefaultApi* | [**preview_image_jpeg_post**](docs/DefaultApi.md#preview_image_jpeg_post) | **POST** /preview/image.jpeg | Get last preview image in JPEG format using custom settings
*DefaultApi* | [**preview_image_tiff_get**](docs/DefaultApi.md#preview_image_tiff_get) | **GET** /preview/image.tiff | Get last preview image in TIFF format
*DefaultApi* | [**preview_pedestal_tiff_get**](docs/DefaultApi.md#preview_pedestal_tiff_get) | **GET** /preview/pedestal.tiff | Get pedestal G0 in TIFF format
*DefaultApi* | [**roi_box_get**](docs/DefaultApi.md#roi_box_get) | **GET** /roi/box | Get box ROIs
*DefaultApi* | [**roi_box_put**](docs/DefaultApi.md#roi_box_put) | **PUT** /roi/box | Upload box ROIs
*DefaultApi* | [**roi_circle_get**](docs/DefaultApi.md#roi_circle_get) | **GET** /roi/circle | Get circular ROI
*DefaultApi* | [**roi_circle_put**](docs/DefaultApi.md#roi_circle_put) | **PUT** /roi/circle | Upload circular ROI
*DefaultApi* | [**start_post**](docs/DefaultApi.md#start_post) | **POST** /start | Start detector
*DefaultApi* | [**statistics_calibration_get**](docs/DefaultApi.md#statistics_calibration_get) | **GET** /statistics/calibration | Get calibration statistics
*DefaultApi* | [**statistics_data_collection_get**](docs/DefaultApi.md#statistics_data_collection_get) | **GET** /statistics/data_collection | Get data collection statistics
*DefaultApi* | [**statistics_get**](docs/DefaultApi.md#statistics_get) | **GET** /statistics | Get general statistics
*DefaultApi* | [**status_get**](docs/DefaultApi.md#status_get) | **GET** /status | Get Jungfraujoch status
*DefaultApi* | [**trigger_post**](docs/DefaultApi.md#trigger_post) | **POST** /trigger | Send soft trigger to the detector
*DefaultApi* | [**version_get**](docs/DefaultApi.md#version_get) | **GET** /version | 
*DefaultApi* | [**wait_till_done_post**](docs/DefaultApi.md#wait_till_done_post) | **POST** /wait_till_done | Wait for acquisition done
*DefaultApi* | [**xfel_event_code_get**](docs/DefaultApi.md#xfel_event_code_get) | **GET** /xfel/event_code | Return XFEL event codes for the current data acquisition
*DefaultApi* | [**xfel_pulse_id_get**](docs/DefaultApi.md#xfel_pulse_id_get) | **GET** /xfel/pulse_id | Return XFEL pulse IDs for the current data acquisition


## Documentation For Models

 - [AzimIntSettings](docs/AzimIntSettings.md)
 - [BrokerStatus](docs/BrokerStatus.md)
 - [CalibrationStatisticsInner](docs/CalibrationStatisticsInner.md)
 - [DatasetSettings](docs/DatasetSettings.md)
 - [DatasetSettingsUnitCell](docs/DatasetSettingsUnitCell.md)
 - [Detector](docs/Detector.md)
 - [DetectorList](docs/DetectorList.md)
 - [DetectorListDetectorsInner](docs/DetectorListDetectorsInner.md)
 - [DetectorModule](docs/DetectorModule.md)
 - [DetectorModuleDirection](docs/DetectorModuleDirection.md)
 - [DetectorPowerState](docs/DetectorPowerState.md)
 - [DetectorSelection](docs/DetectorSelection.md)
 - [DetectorSettings](docs/DetectorSettings.md)
 - [DetectorState](docs/DetectorState.md)
 - [DetectorStatus](docs/DetectorStatus.md)
 - [DetectorTiming](docs/DetectorTiming.md)
 - [DetectorType](docs/DetectorType.md)
 - [ErrorMessage](docs/ErrorMessage.md)
 - [FpgaStatusInner](docs/FpgaStatusInner.md)
 - [ImageFormatSettings](docs/ImageFormatSettings.md)
 - [ImagePusherType](docs/ImagePusherType.md)
 - [InstrumentMetadata](docs/InstrumentMetadata.md)
 - [JfjochSettings](docs/JfjochSettings.md)
 - [JfjochStatistics](docs/JfjochStatistics.md)
 - [MeasurementStatistics](docs/MeasurementStatistics.md)
 - [PcieDevicesInner](docs/PcieDevicesInner.md)
 - [Plot](docs/Plot.md)
 - [Plots](docs/Plots.md)
 - [PreviewSettings](docs/PreviewSettings.md)
 - [RoiBox](docs/RoiBox.md)
 - [RoiBoxList](docs/RoiBoxList.md)
 - [RoiCircle](docs/RoiCircle.md)
 - [RoiCircleList](docs/RoiCircleList.md)
 - [RotationAxis](docs/RotationAxis.md)
 - [SpotFindingSettings](docs/SpotFindingSettings.md)
 - [StandardDetectorGeometry](docs/StandardDetectorGeometry.md)
 - [ZeromqPreviewSettings](docs/ZeromqPreviewSettings.md)
 - [ZeromqSettings](docs/ZeromqSettings.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization

Endpoints do not require authorization.


## Author

filip.leonarski@psi.ch


